@@ -18,19 +18,17 @@ class Loader(yaml.SafeLoader):
 
     def __init__(self, stream: IO) -> None:
         """Initialise Loader."""
-
         try:
-            self._root = os.path.split(stream.name)[0]
+            self.root = os.path.split(stream.name)[0]
         except AttributeError:
-            self._root = os.path.curdir
+            self.root = os.path.curdir
 
         super().__init__(stream)
 
 
 def construct_include(loader: Loader, node: yaml.Node) -> Any:
     """Include file referenced at node."""
-
-    relative_path = os.path.join(loader._root, loader.construct_scalar(node))
+    relative_path = os.path.join(loader.root, loader.construct_scalar(node))
     full_path = os.path.abspath(relative_path)
 
     with open(full_path, "r") as f:
@@ -38,7 +36,10 @@ def construct_include(loader: Loader, node: yaml.Node) -> Any:
 
 
 def load_config_file(file_path):
-    """ Loads configuration file. If non-empty file exists reads data and returns it """
+    """
+    Loads configuration file. If non-empty file exists reads data and
+    returns it.
+    """
     with open(file_path, "r") as stream:
         logger.info(f"Loading file {file_path}")
         data = yaml.load(stream, Loader)
